@@ -1,6 +1,6 @@
 package App::Info::Request;
 
-# $Id: Request.pm 902 2004-12-07 00:48:37Z theory $
+# $Id: Request.pm 2193 2005-11-08 06:05:50Z theory $
 
 =head1 NAME
 
@@ -44,7 +44,7 @@ to handle the request appropriately.
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.43';
+$VERSION = '0.46';
 
 ##############################################################################
 
@@ -120,6 +120,21 @@ sub new {
 
 =head2 Object Methods
 
+=head3 key
+
+  my $key = $req->key;
+
+Returns the key stored in the App::Info::Request object. The key is used by
+the App::Info subclass to uniquely identify the information it is harvesting,
+such as the path to an executable. It might be used by request handlers,
+for example, to see if an option was passed on the command-line.
+
+=cut
+
+sub key { $_[0]->{key} }
+
+##############################################################################
+
 =head3 message
 
   my $message = $req->message;
